# Build Packager

You can use Molot for orchestrating simple build tasks in your project.

Imagine we want to package files as a ZIP distribution for a serverless function. See [build.py](./build.py) for an example implementation.

## Running

You can run the packaging target like so:

```shell
./build.py package
```
